==> openGion6.6.0.1_dev.zip: uap/webapps/ge/db/MYSQL/sql/install/01_TABLE/GEA06S.sql <==
/****************************************************************************/
/* GEA06 ( ﾃﾞｰﾀﾛｰﾙﾏｽﾀ )                                                     */
/*                                                                          */
/* Created : 2016/10/27 10:56:51                                            */
/****************************************************************************/

CREATE TABLE GEA06 (
   SYSTEM_ID    VARCHAR (  10 )                 NOT NULL                                                /*  10 ｼｽﾃﾑID   */
 , DROLE        VARCHAR (  20 )                 NOT NULL                                                /*  20 ﾃﾞｰﾀﾛｰﾙ  */
 , CLM          VARCHAR (  30 )                 NOT NULL                                                /*  30 項目     */
 , CVALUE       VARCHAR ( 200 )                 NOT NULL                                                /*  40 値       */
 , VALCDTN      VARCHAR (  10 )                 NOT NULL                                                /*  50 条件     */
 , UNIQ         BIGINT                          NOT NULL    AUTO_INCREMENT  , PRIMARY KEY(UNIQ)         /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          VARCHAR (   1 )     DEFAULT '1' NOT NULL                                                /* 810 状態ﾌﾗｸﾞ */
 , DYSET        VARCHAR (  14 )                                                                         /* 820 登録日時 */
 , PGSET        VARCHAR (  10 )                                                                         /* 830 作成PG   */
 , PGPSET       VARCHAR (  10 )                                                                         /* 840 作成親PG */
 , USRSET       VARCHAR (  10 )                                                                         /* 850 作成社員 */
 , DYUPD        VARCHAR (  14 )                                                                         /* 860 更新日時 */
 , PGUPD        VARCHAR (  10 )                                                                         /* 870 更新PG   */
 , PGPUPD       VARCHAR (  10 )                                                                         /* 880 更新親PG */
 , USRUPD       VARCHAR (  10 )                                                                         /* 890 更新者   */
);

==> openGion7.0.5.0_dev.zip: uap/webapps/ge/db/MYSQL/sql/install/01_TABLE/GEA06S.sql <==
/****************************************************************************/
/* GEA06 ( ﾃﾞｰﾀﾛｰﾙﾏｽﾀ )                                                     */
/*                                                                          */
/* Created : 2018/09/28 16:03:25                                            */
/****************************************************************************/

CREATE TABLE GEA06 (
   SYSTEM_ID    VARCHAR (  10 )                 NOT NULL                                                /*  10 ｼｽﾃﾑID   */
 , DROLE        VARCHAR (  20 )                 NOT NULL                                                /*  20 ﾃﾞｰﾀﾛｰﾙ  */
 , CLM          VARCHAR (  30 )                 NOT NULL                                                /*  30 項目     */
 , CVALUE       VARCHAR ( 200 )                 NOT NULL                                                /*  40 値       */
 , VALCDTN      VARCHAR (  10 )                 NOT NULL                                                /*  50 条件     */
 , UNIQ         BIGINT                          NOT NULL    AUTO_INCREMENT  , PRIMARY KEY(UNIQ)         /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          VARCHAR (   1 )     DEFAULT '1' NOT NULL                                                /* 810 状態ﾌﾗｸﾞ */
 , DYSET        VARCHAR (  14 )                                                                         /* 820 登録日時 */
 , PGSET        VARCHAR (  10 )                                                                         /* 830 作成PG   */
 , PGPSET       VARCHAR (  10 )                                                                         /* 840 作成親PG */
 , USRSET       VARCHAR (  10 )                                                                         /* 850 作成者   */
 , DYUPD        VARCHAR (  14 )                                                                         /* 860 更新日時 */
 , PGUPD        VARCHAR (  10 )                                                                         /* 870 更新PG   */
 , PGPUPD       VARCHAR (  10 )                                                                         /* 880 更新親PG */
 , USRUPD       VARCHAR (  10 )                                                                         /* 890 更新者   */
);
